# MediaGoblin for LibrePlanet
# Copyright (C) 2015 David Thompson <davet@gnu.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging
import os

from mediagoblin import mg_globals
from mediagoblin.tools.pluginapi import get_config, register_template_path, register_routes
from mediagoblin.db.models import MediaEntry
from mediagoblin.db.util import media_entries_for_tag_slug
from mediagoblin.tools.pagination import Pagination
from mediagoblin.tools.response import render_to_response
from mediagoblin.tools.licenses import SORTED_LICENSES, SUPPORTED_LICENSES, License
from mediagoblin.decorators import uses_pagination, user_not_banned

# Add CC BY-SA 4.0 to licenses
cc_by_sa_4 = License("CC BY-SA 4.0",
                     "Creative Commons Attribution-ShareAlike 4.0 International",
                     "https://creativecommons.org/licenses/by-sa/4.0/")
SORTED_LICENSES.insert(1, cc_by_sa_4)
SUPPORTED_LICENSES[cc_by_sa_4.uri] = cc_by_sa_4

PLUGIN_DIR = os.path.dirname(__file__)
MAX_HOME_ITEMS = 20

_log = logging.getLogger(__name__)

# This is the function that gets called when the setup
# hook fires.
def setup_plugin():
    _log.info("Setting up Libreplanet...")

    # Register the template path.
    register_template_path(os.path.join(PLUGIN_DIR, 'templates'))

def lp_media_for_type(db, type, tag=None):
    if (tag == None):
        cursor = MediaEntry.query
    else:
        cursor = media_entries_for_tag_slug(db, tag)

    return cursor.\
        filter((MediaEntry.media_type == type)
               & (MediaEntry.state == u'processed')).\
        order_by(MediaEntry.created.desc()).\
        limit(MAX_HOME_ITEMS)

@user_not_banned
def frontpage_view(request):
    images = lp_media_for_type(request.db, u'mediagoblin.media_types.image')
    videos = lp_media_for_type(request.db, u'mediagoblin.media_types.video')

    return render_to_response(
        request, 'libreplanet/root.html',
        {'images': images,
         'videos': videos,
         'allow_registration': mg_globals.app_config["allow_registration"]})

def frontpage_view_hook():
    return frontpage_view

register_routes([('all-videos', '/videos',
                  'mediagoblin.plugins.libreplanet.views:video_listing'),
                 ('all-photos', '/photos',
                  'mediagoblin.plugins.libreplanet.views:image_listing')
             ])

# This is a dict that specifies which hooks this plugin uses.
# This one only uses one hook: setup.
hooks = {
    'setup': setup_plugin,
    'frontpage_view': frontpage_view_hook
}
